AnnaDB python driver

## Install

```shell
pip install annadb
```

## Connect

```python
from annadb import Connection

conn = Connection.from_connection_string("annadb://localhost:10001")
```

## Tutorial

Please, follow the official tutorial to meet all the features

<https://annadb.dev/tutorial/python/>